@@ -16,7 +16,7 @@ def get_hash(short=False):
     if uncommitted_changes():
         logging.warning("*** Uncommitted changes present - Build container version might be outdated ***")
 
-    return subprocess.check_output(git_command).decode().strip()
+    return subprocess.check_output(git_command).strip()
 
 
 def uncommitted_changes():
